@@ -23,18 +23,6 @@ def test_question_jexl_validate(expression, num_errors):
     assert len(list(jexl.validate(expression))) == num_errors
 
 
-@pytest.mark.parametrize(
-    "expression,result",
-    [
-        ("[{ key: 1 }]|mapby('key')", [1]),
-        ("[{ otherkey: 1 }]|mapby('key')", [None]),
-        ("[]|mapby('key')", []),
-    ],
-)
-def test_mapby_operator(expression, result):
-    assert QuestionJexl().evaluate(expression) == result
-
-
 @pytest.mark.parametrize(
     "expression,result",
     [
@@ -343,7 +331,7 @@ def test_answer_transform_on_hidden_question_types(
     table = questions["table"]
     row_form = table.row_form
     row_doc = document_factory(form=row_form)
-    answer_factory(document=row_doc, question_id="column")
+    answer_factory(document=row_doc, question=questions["column"])
     answers["table"].documents.add(row_doc)
 
     questions["form"].is_hidden = (
